@@ -119,8 +119,8 @@ pub fn parse_possibly_prefixed_tag_version(package_name: Option<&str>, tag_name:
 }
 
 pub fn parse_tag_version(name: &BStr) -> Option<Version> {
-    name.strip_prefix(b"v")
-        .and_then(|v| v.to_str().ok())
+    name.find_byteset(b"0123456789")
+        .and_then(|pos| name[pos..].to_str().ok())
         .and_then(|v| Version::parse(v).ok())
 }
 
@@ -246,20 +246,21 @@ mod tests {
             fn not_enough_numbers() {
                 assert!(!is_tag_version(b"v0.0".as_bstr()));
             }
-            #[test]
-            fn invalid_prefix() {
-                assert!(!is_tag_version(b"x0.0.1".as_bstr()));
-            }
 
             #[test]
             fn funky() {
-                assert!(!is_tag_version(b"vers0.0.1".as_bstr()));
                 assert!(!is_tag_version(b"vHi.Ho.yada-anythingreally".as_bstr()));
             }
         }
         mod matches {
             use git_repository::bstr::ByteSlice;
 
+            #[test]
+            fn custom_prefix() {
+                assert!(is_tag_version(b"x0.0.1".as_bstr()));
+                assert!(is_tag_version(b"vers0.0.1".as_bstr()));
+            }
+
             use crate::utils::is_tag_version;
 
             #[test]
